getPostCodes method

List<PostCode?>? getPostCodes()

Returns list of PostCode object

this method return every post code data in the daira and return the result as list of PostCode

Implementation

List<PostCode?>? getPostCodes() {
  return algeria_postcodes.where((element) => ((element['daira_name'] == data!['daira_name']))).map((e) => PostCode(data: e)).toSet().toList();
}